@@ -10,9 +10,9 @@ use JSON::XS;
 my $json    = JSON::XS->new();
 my $logger  = Log::Handler->new();
 my $gearman = Log::Handler::Output::Gearman->new(
-    servers        => ['127.0.0.1'],
-    worker         => 'logger',
-    encode_message => sub { return $json->encode( { message => shift } ) }
+    servers         => ['127.0.0.1'],
+    worker          => 'logger',
+    prepare_message => sub { return $json->encode( { message => shift } ) }
 );
 
 my %handler_options = (
